# -*- coding: UTF-8 -*-
VUE_CONFIGURATION = [
    {
        'name': 'vue',
        'use_local': False,
        'cdn': 'cloudflare',
        'version': '1.0.28'
    },
    {
        'name': 'vue-async-data',
        'use_local': False,
        'cdn': 'cloudflare',
        'version': '1.0.2'
    },
    {
        'name': 'vue-form',
        'use_local': False,
        'cdn': 'cloudflare',
        'version': '0.3.1'
    },
    {
        'name': 'vue-i18n',
        'use_local': False,
        'cdn': 'cloudflare',
        'version': '4.6.0'
    },
    {
        'name': 'vue-resource',
        'use_local': False,
        'cdn': 'cloudflare',
        'version': '1.0.3'
    },
    {
        'name': 'vue-router',
        'use_local': False,
        'cdn': 'cloudflare',
        'version': '0.7.13'
    },
    {
        'name': 'vue-validator',
        'use_local': False,
        'cdn': 'cloudflare',
        'version': '2.1.7'
    },
    {
        'name': 'vue-table',
        'use_local': False,
        'cdn': 'jsdelivr',
        'version': '1.5.3'
    },
    {
        'name': 'vuex',
        'use_local': False,
        'cdn': 'cloudflare',
        'version': '2.0.0'
    },
    {
        'name': 'vue-strap',
        'use_local': False,
        'cdn': 'cloudflare',
        'version': '1.1.29'
    }
]
